/********************************************************************
 FileName:    	main.c
 Dependencies: 	aguijon.h
 Hardware:	Aguijon rev3.0 & rev4.0
 Complier:  	Microchip XC16, C30
 Company:	Vinagrn Digital
 Author:	Juan Carlos Orozco Gutierrez

 Software License Agreement:

 This software has been licensed under the GNU General Public
 License is intended to guarantee your freedom to share and change free
 software--to make sure the software is free for all its users.

********************************************************************
 File Description:
    Main Application file

 Change History:
  Rev   Description                                 Modified by:
  ----  -----------------------------------------  --------------
  1.0   Initial release                             JCOG
  2.0   Updated with [VD]HammerHead 1.0 libraries   JCOG

 For extra documentation and support:
 *  http://www.vinagrondigital.com
********************************************************************/
#include "aguijon.h"
#include "analog.h"             //analog support
#include "EEPROM.h"             //EEPROM support
#include "IO.h"                 //IO support
#include "inputs.h"             //inputs support
#include "LCD.h"                //LCD support
#include "outputs.h"            //output support
#include "realtime.h"           //RTCC module support
#include "RS232.h"              //RS232 support
#include "timers.h"             //timers support






///////////////////////////////////////
void HammerHead_Init(void)
{
    /*GPIO*/
    IO_Init();        //initialize all ports

    /*Inputs*/
    ADC_Init();

    /*UART*/
    RS232_Init(BAUD19200);  //set 19200bps as UART speed

    /*LCD*/
    LCD_Init(LCD_MODE_1);

#if defined(USE_LCD_EXTRA_FEATURES)
    LCD_BacklightFadeIn();
#else
    LCD_BacklightSet(BLIGHT_LVL_4);
#endif

    /*RTCC*/
    RTCC_Init();    //interurpt is handled inside realtime.c
    RTCC_Enable();

    /*timers*/
    Timer1_Init();
    Timer1_SetTick(TIMER_TICK_50MS);
    Timer1_Enable();        //interupt is handled inside timers.c

    Timer4_Init();
    Timer4_SetTick(TIMER_TICK_100MS);
    Timer4_Enable();        //interupt is handled inside timers.c

    LEDport_Set(0xFF,ON);
}

///////////////////////////////////////
int main(void)
{
    int adc  	 = 0;
    int dipsw    = 0;
    int inputs   = 0;
    int keyboard = 0;
    char msg[20];

    HammerHead_Init();  //initialize [VD]HammerHead
    LCD_IntroAnimation();

    /*Send some stuff via RS232*/
    RS232_PutStr((unsigned int *)"\r\nWelcome to " HAMMERHEAD_DEVICE "\n");
    RS232_PutStr((unsigned int *)"\ryour board is running HammerHead " HAMMERHEAD_VERSION "\n");
    RS232_PutStr((unsigned int *)"\rcompile date:\n" );
    RS232_PutStr((unsigned int *)__DATE__" "__TIME__);
    RS232_PutStr((unsigned int *)"\r\nSend me some data, and watch LED8 change!\n\r" );

    OC_PWMChannelConfig(4); //config PWM in open collector #1

    EEPROM_WriteByte(0x01,0xDE); //write 0xDE in EEPROM addr 0x01

    Buzzer_Chime();

    /*Read EEPROM and display it */
    adc = EEPROM_ReadByte(0x01);
    sprintf(msg,"EEPROM data:0x%.2X",adc);
    LCD_PutStr(1,0,msg,TRUE);

    delayms(500);

    for(;;){
        adc   = ADC_Read();     //get ADC value
        dipsw = DIPSW_Read();   //get DIPsw value

        sprintf(msg,"DIP:0x%.2X ADC:%u",dipsw,adc); //prepare string
		LCD_PutStr(2,0,msg,FALSE);      //display DIP value        

        keyboard = SW_Read();   //read keyboard
        inputs   = IN_Read();   //read inputs

        OC_PWMSet(200,ADC_Range(5,95)); //set OC_PWM period and duty cycle

        switch(inputs){
            case 1: LEDport_Set(0x55,ON); break;    //set LEDport to 0x55 with input 1
            case 2: LEDport_Set(0xAA,ON); break;    //set LEDport to 0xAA with input 2
            case 3: LEDport_Set(0x3C,ON); break;    //set LEDport to 0x3C with input 3
            case 4: LEDport_Set(0x4D,ON); break;    //set LEDport to 0x4D with input 4
        }

        switch(keyboard){
            case 1:
               RLY_Toggle(1);  //Toggle Relay 1                
                break;
            case 2:                                
               RLY_Toggle(1);  //Toggle Relay 2
               OC_Toggle(2);   //Toggle OC 2
                break;
            case 3:
                RLY_Toggle(3);  //Toggle Relay 3
                OC_Toggle(3);   //Toggle OC 3
                break;
            case 4:                
                if(RLY_Get(4) == OFF){
                    RLY_Set(4,ON);
                    OC_Set(4,ON);
                }else{
                    RLY_Set(4,OFF);
                    OC_Set(4,OFF);
                }
                break;
        }

        delayms(50);

//#if defined(AGUIJON_REV_4) || defined(AGUIJON_REV_41)
//        WDOG_PIN = ~WDOG_PIN; //feed the dog
//#endif
    }

    return 0;
}
